import React, { useEffect, useRef } from 'react';
import ReactDOM from 'react-dom';
import FoundationLightboxOverlay from './FoundationLightboxOverlay';

function getPortalRootElement(portalRootElementId, callback) {
  var root = document.getElementById(portalRootElementId);

  if (root !== null) {
    callback(root);
  } else {
    if (process.env.NODE_ENV !== 'production') {
      console.warn("[FoundationLightbox] Unable to find portal root `#".concat(portalRootElementId, "`."));
    }
  }
}

export default function FoundationLightbox(props) {
  var portalRootElementId = 'foundation-lightbox-portal-root';
  var ref = useRef(document.createElement('div'));
  ref.current.className = 'foundation-lightbox-portal-container';
  useEffect(function () {
    var el = ref.current;
    getPortalRootElement(portalRootElementId, function (root) {
      root.appendChild(el);
    });
    return function () {
      getPortalRootElement(portalRootElementId, function (root) {
        root.removeChild(el);
      });
    };
  }, []);
  return ReactDOM.createPortal(React.createElement(FoundationLightboxOverlay, props), ref.current);
}
//# sourceMappingURL=FoundationLightbox.js.map